# Invpy package v1.1.1

- Package that includes several methods to compute statistical translation non-invariance of primarly, but not limitted to, scalar
cosmological fields.

## Major Bug fixes v1.1.0

- Fixed second and first kind estimator bias in pbc_estimators.py method.

## Minor Bug fixes v1.1.1

- Fixed second kind estimator bias in pbc_estimators.py method;
- Fixed bugs on common.py.

## Updates

- No new features up to date.



